token

package
v0.0.0-...-8d3bc00 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidToken = errors.New("token is invalid")
	ErrExpiredToken = errors.New("token has expired")
)

Different type of error returned by the verifytoken function

Functions

This section is empty.

Types

type JWTMaker

type JWTMaker struct {
	// contains filtered or unexported fields
}

JWTMaker is a JSON Web Token maker

func (*JWTMaker) CreateToken

func (maker *JWTMaker) CreateToken(username string, duration time.Duration) (string, error)

CreateToken creates a new token for a specific username and duration

func (*JWTMaker) VerifyToken

func (maker *JWTMaker) VerifyToken(token string) (*Payload, error)

VerifyToken checks if the token is valid or not

type Maker

type Maker interface {
	// CreateToken creates a new token for a specific username and duration
	CreateToken(username string, duration time.Duration) (string, error)

	// VerifyToken checks if the token is valid or not
	VerifyToken(token string) (*Payload, error)
}

What is payload data of the token? Maker is an interface for managing tokens

func NewJWTMaker

func NewJWTMaker(secretKey string) (Maker, error)

NewJWTMaker

type Payload

type Payload struct {
	ID uuid.UUID `json:"id"`
	*jwt.RegisteredClaims
}

func NewPayload

func NewPayload(username string, duration time.Duration) (*Payload, error)

NewPayload creates a new token payload with a specific username and duration

func (*Payload) Validate

func (payload *Payload) Validate() error

Jump to