Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidToken = errors.New("token is invalid") ErrExpiredToken = errors.New("token has expired") )
Different type of error returned by the verifytoken function
Functions ¶
This section is empty.
Types ¶
type JWTMaker ¶
type JWTMaker struct {
// contains filtered or unexported fields
}
JWTMaker is a JSON Web Token maker
func (*JWTMaker) CreateToken ¶
CreateToken creates a new token for a specific username and duration
type Maker ¶
type Maker interface {
// CreateToken creates a new token for a specific username and duration
CreateToken(username string, duration time.Duration) (string, error)
// VerifyToken checks if the token is valid or not
VerifyToken(token string) (*Payload, error)
}
What is payload data of the token? Maker is an interface for managing tokens
type Payload ¶
type Payload struct {
ID uuid.UUID `json:"id"`
*jwt.RegisteredClaims
}
func NewPayload ¶
NewPayload creates a new token payload with a specific username and duration
Click to show internal directories.
Click to hide internal directories.